@@ -3,7 +3,7 @@
 #define private static
 #define public 
 
-#define  ISSEPARATOR(x) ('='==(x))
+#define  ISSEPARATOR(x) (('='==(x))||(':'==(x)))
 #define  ISSPACE(x)     isspace((unsigned char)(x))
 #define  ISOPERAND(x) ('<'==(x)||'>'==(x)||'='==(x))
 #define  ISDIGIT(x)     isdigit ((unsigned char)(x)) 
