@@ -23,6 +23,7 @@
  */
 #include <util.h>
 #include <error.h>
+#include <memory.h>
 
 /**
  * substring        returns a char pointer from
@@ -33,7 +34,6 @@ char *
 substring(char *buffer, int start, int length)
 {
   char *sub;
-  sub = malloc (sizeof (char) * (length + 1));
 	
   if ((length < 1) || (start < 0) || (start > (int)strlen (buffer)))
     return NULL;
@@ -43,14 +43,11 @@ substring(char *buffer, int start, int length)
     return buffer;
   }
 
-  if (sub == NULL){
-    joe_fatal( "insufficient memory." );
-  }
-
+  sub = xmalloc(sizeof(char) * length + 1);
   memset (sub, '\0', length + 1);
 
   buffer += start;
-  strncpy( sub, buffer, length );
+  memcpy(sub, buffer, length);
 
   return sub;
 }
