@@ -10,10 +10,10 @@ add_authorization(SERVICE service, char *username, char *password, char *realm)
 {
   struct LOGIN *tail = NULL;
   tail = (struct LOGIN*)xmalloc(sizeof(struct LOGIN));
-  tail->username = xstrdup( username );
-  tail->password = xstrdup( password );
+  tail->username = xstrdup(username);
+  tail->password = xstrdup(password);
   tail->realm    = (realm!=NULL&&strlen(realm)>1)?xstrdup( realm ):"all";
-  switch( service ){
+  switch(service){
   case WWW:
     tail->next   = my.auth.head;
     my.auth.head = tail;
@@ -29,38 +29,37 @@ add_authorization(SERVICE service, char *username, char *password, char *realm)
 } 
 
 int
-display_authorization( SERVICE service )
+display_authorization(SERVICE service)
 {
   struct LOGIN *li = (service==WWW)?my.auth.head:my.proxy.head;
 
-  while( li != NULL ){
-    printf("%s:%s [%s]\n", li->username, li->password, li->realm );
+  while(li != NULL){
+    printf("%s:%s [%s]\n", li->username, li->password, li->realm);
     li = li->next; 
   }
   return 0;
 }
 
 int
-set_authorization( SERVICE service, char *realm ) 
+set_authorization(SERVICE service, char *realm) 
 {
   char buf[64];
   struct LOGIN *li     = (service==WWW)?my.auth.head:my.proxy.head;
   pthread_mutex_t lock = (service==WWW)?my.auth.lock:my.proxy.lock;
  
   while( li != NULL ){
-    if( !strncasecmp( li->realm, realm, strlen( realm ))){ 
+    if(!strncasecmp(li->realm, realm, strlen(realm))){ 
       pthread_mutex_lock(&(lock)); 
       snprintf( 
-        buf, sizeof( buf ), 
+        buf, sizeof(buf), 
         "%s:%s", 
         (li->username!=NULL)?li->username:"", (li->password!=NULL)?li->password:"" 
       ); 
-      if( service==WWW ){
+      if(service==WWW){
         if(( base64_encode( buf, strlen(buf), &my.auth.encode ) < 0 ))
           return -1;
-      }
-      else {
-        if(( base64_encode( buf, strlen(buf), &my.proxy.encode ) < 0 ))
+      } else {
+        if((base64_encode( buf, strlen(buf), &my.proxy.encode ) < 0))
           return -1;
       }
       pthread_mutex_unlock(&(lock)); 
@@ -81,8 +80,7 @@ set_authorization( SERVICE service, char *realm )
   if( service==WWW ){
     if(( base64_encode( buf, strlen(buf), &my.auth.encode ) < 0 ))
       return -1;
-  }
-  else{
+  } else {
     if(( base64_encode( buf, strlen(buf), &my.proxy.encode ) < 0 ))
       return -1;
   }
