@@ -112,8 +112,7 @@ start_routine(CLIENT *client)
   #endif
     pthread_setcancelstate(PTHREAD_CANCEL_ENABLE, &state);
 #endif/*SIGNAL_CLIENT_PLATFORM*/ 
-
-  if( my.login == TRUE ){
+  if(my.login == TRUE){
     http_request(C, add_url(my.loginurl, 0), client);
   }
 
@@ -143,6 +142,7 @@ start_routine(CLIENT *client)
     }
 
     if(client->U[y] != NULL && client->U[y]->hostname != NULL){
+      client->auth.bids.www = 0; /* reset */
       if((ret = http_request(C, client->U[y], client))==FALSE){
         increment_failures();
       }
@@ -301,7 +301,7 @@ http_request(CONN *C, URL *U, CLIENT *client)
   if(!head){  C->connection.reuse = 0; socket_close(C); return FALSE; } 
 */
 
-  if((head = http_read_headers(C, U->hostname))==NULL){
+  if((head = http_read_headers(C, U))==NULL){
     C->connection.reuse = 0; 
     socket_close(C); 
     debug("NULL headers: %s:%d", __FILE__, __LINE__);
@@ -328,6 +328,10 @@ http_request(CONN *C, URL *U, CLIENT *client)
   client->time  += etime;
   client->code  += code;
   client->fail  += fail;
+  if(head->code == 200){
+    client->ok200++;
+  }
+
   /**
    * check to see if this transaction is the longest or shortest
    */
@@ -422,7 +426,7 @@ http_request(CONN *C, URL *U, CLIENT *client)
        * Proxy-Authenticate challenge from the proxy server.
        */
       client->auth.proxy = (client->auth.proxy==0)?1:client->auth.proxy;
-      if(( client->auth.bids.proxy++ ) < my.bids - 1 ){
+      if((client->auth.bids.proxy++) < my.bids - 1){
         if(head->auth.type.proxy == DIGEST){
           client->auth.type.proxy =  DIGEST;
           break;
@@ -478,5 +482,6 @@ increment_failures()
   pthread_mutex_lock(&(my.lock));  
   my.failed++;
   pthread_mutex_unlock(&(my.lock));  
+  pthread_testcancel();
 }
 
