@@ -1,7 +1,7 @@
 /**
  * Thread Pool 
  *
- * Copyright (C) 2005-2007 by
+ * Copyright (C) 2005-2008 by
  * Jeffrey Fulmer - <jeff@joedog.org>, et al. 
  *
  * This program is free software; you can redistribute it and/or modify
@@ -234,8 +234,22 @@ crew_join(CREW crew, BOOLEAN finish, void **payload)
   crew->closed = TRUE;
 
   if(finish == TRUE){
-    while(crew->cursize != 0){
-      if((c = pthread_cond_wait(&(crew->empty), &(crew->lock))) != 0){
+    while((crew->cursize != 0) && (!crew->shutdown)){
+      int rc;
+      struct timespec ts;
+      struct timeval tp;
+
+      rc = gettimeofday(&tp,NULL);
+      if( rc != 0 )
+        perror("gettimeofday");
+      ts.tv_sec = tp.tv_sec+60;
+      ts.tv_nsec = tp.tv_usec*1000;
+      rc = pthread_cond_timedwait(&(crew->empty), &(crew->lock), &ts );
+      if(rc==ETIMEDOUT) {
+        pthread_mutex_unlock(&crew->lock);
+      }
+
+      if( rc != 0){
 	joe_fatal("pthread wait");
       }
     }
@@ -269,7 +283,7 @@ void crew_destroy(CREW crew) {
 
   free(crew->threads);
   while(crew->head != NULL){
-    workptr  = crew->head->next; 
+    workptr  = crew->head; 
     crew->head = crew->head->next;
     free(workptr);
   }
@@ -283,9 +297,9 @@ void crew_destroy(CREW crew) {
 public void 
 crew_set_shutdown(CREW this, BOOLEAN shutdown)
 {
-  pthread_mutex_lock(&this->lock);
+//  pthread_mutex_lock(&this->lock);
   this->shutdown = shutdown;
-  pthread_mutex_unlock(&this->lock);
+//  pthread_mutex_unlock(&this->lock);
   
   pthread_cond_broadcast(&this->not_empty);
   pthread_cond_broadcast(&this->not_full);
