@@ -76,7 +76,7 @@ https_tunnel_response(CONN *C)
     memset( &line, 0, sizeof( line ));
     while((n = read(C->sock, &c, 1)) == 1){
       line[x] = c;
-      if(my.debug || my.get){ printf("%c", c ); fflush(stdout); }
+      if(my.debug || my.get){ printf("%c", c); fflush(stdout); }
       if((line[0] == '\n') || (line[1] == '\n')){
         return code;
       }
@@ -106,6 +106,11 @@ http_get(CONN *C, URL *U)
   char portstr[16];
   char fullpath[4096];
   char cookie[MAX_COOKIE_SIZE+8];
+  time_t now;
+  char *ifmod = url_get_if_modified_since(U);
+  char *ifnon = url_get_etag(U);
+
+  now = time(NULL);
 
   memset(cookie,  0, sizeof cookie);
   memset(request, 0, sizeof request);
@@ -150,30 +155,39 @@ http_get(CONN *C, URL *U)
    */
   rlen = snprintf(
     request, sizeof( request ),
-    "GET %s %s\015\012"
-    "Host: %s%s\015\012" 
-    "%s"
-    "%s"
-    "%s"
-    "Accept: */*\015\012"
-    "Accept-Encoding: %s\015\012"
-    "User-Agent: %s\015\012%s"
-    "Connection: %s\015\012\015\012",  
+    "GET %s %s\015\012"                    /* fullpath, protocol     */
+    "Host: %s%s\015\012"                   /* U->hostname, portstr   */
+    "%s"                                   /* authwww   or empty str */
+    "%s"                                   /* authproxy or empty str */
+    "%s"                                   /* cookie    or empty str */
+    "%s"                                   /* ifmod     or empty str */
+    "%s"                                   /* ifnon     or empty str */
+    "Accept: */*\015\012"                  /*             */
+    "Accept-Encoding: %s\015\012"          /* my.encoding */
+    "User-Agent: %s\015\012"               /* my uagent   */
+    "%s"                                   /* my.extra    */
+    "Connection: %s\015\012\015\012",      /* keepalive   */
     fullpath, protocol, U->hostname, portstr,
     (C->auth.www==TRUE)?authwww:"",
     (C->auth.proxy==TRUE)?authpxy:"",
     (strlen(cookie) > 8)?cookie:"", 
+    (ifmod!=NULL)?ifmod:"",
+    (ifnon!=NULL)?ifnon:"",
     my.encoding, my.uagent, my.extra, keepalive 
   );
-  
+ 
   if(my.debug || my.get){ printf("%s\n", request); fflush(stdout); }
   if(rlen < 0 || rlen > (int)sizeof(request)) 
     joe_fatal("http_get: request buffer overrun!");
 
   if((socket_write(C, request, rlen)) < 0){
+    xfree(ifmod);
+    xfree(ifnon);
     return -1;
   }
-  
+   
+  xfree(ifmod);
+  xfree(ifnon);
   return 0;
 }
 
@@ -182,7 +196,6 @@ http_get(CONN *C, URL *U)
  * formats and sends an HTTP/1.0 request
  */
 int
-/*http_post(CONN *C, char *host, int port, char *path, char *data, size_t len)*/
 http_post(CONN *C, URL *U)
 {
   int  rlen;
@@ -279,7 +292,7 @@ http_post(CONN *C, URL *U)
  * header information into the struct.
  */
 HEADERS *
-http_read_headers(CONN *C, char *host)
+http_read_headers(CONN *C, URL *U)
 { 
   int  x;           /* while loop index      */
   int  n;           /* assign socket_read    */
@@ -291,7 +304,7 @@ http_read_headers(CONN *C, char *host)
   
   while(TRUE){
     x = 0;
-    memset(&line, 0, sizeof(line));
+    memset(&line, 0, MAX_COOKIE_SIZE);
     while((n = socket_read(C, &c, 1)) == 1){
       if(x < MAX_COOKIE_SIZE - 1)
         line[x] = c; 
@@ -318,7 +331,7 @@ http_read_headers(CONN *C, char *host)
       if(my.cookies){
         memset(h->cookie, 0, sizeof(h->cookie));
         strncpy(h->cookie, line+12, strlen(line));
-        add_cookie(pthread_self(), host, h->cookie);
+        add_cookie(pthread_self(), U->hostname, h->cookie);
       }
     }
     if(strncasecmp(line, "connection: ", 12 ) == 0){
@@ -364,6 +377,27 @@ http_read_headers(CONN *C, char *host)
       memcpy(h->redirect, line+10, len-10);
       h->redirect[len-10] = 0;
     }
+    if(strncasecmp(line, "last-modified: ", 15) == 0){
+      char *date;
+      size_t len = strlen(line);
+      if(my.cache){
+        date = xmalloc(len);
+        memcpy(date, line+15, len-14);
+        url_set_last_modified(U, date);
+        xfree(date); 
+      }
+    }
+    if(strncasecmp(line, "etag: ", 6) == 0){
+      char   *etag;
+      size_t len = strlen(line);
+      if(my.cache){
+        etag = xmalloc(len);
+        memcpy(etag, line+6, len-5);
+        etag[len-1] = '\0';
+        url_set_etag(U, etag);
+        xfree(etag);
+      }
+    }
     if(strncasecmp(line, "www-authenticate: ", 18) == 0){
       char *tmp;
       h->auth.www = TRUE;
