@@ -69,7 +69,7 @@ struct headers
 /* http function prototypes */
 int      http_get (CONN *C, URL *U);
 int      http_post(CONN *C, URL *U);
-HEADERS *http_read_headers(CONN *C, char *);
+HEADERS *http_read_headers(CONN *C, URL *U);
 ssize_t  http_read(CONN *C);
 BOOLEAN  https_tunnel_request(CONN *C, char *host, int port);
 int      https_tunnel_response(CONN *C);
