@@ -43,7 +43,7 @@ init_config( void )
    * use default of ~/.siegerc */
   if(strcmp(my.rc, "") == 0){
     if((e = getenv("SIEGERC")) != NULL){
-      snprintf( my.rc, sizeof( my.rc ), e);
+      snprintf(my.rc, sizeof(my.rc), e);
     } else {
       snprintf(my.rc, sizeof(my.rc), "%s/.siegerc", getenv("HOME"));
     }
@@ -116,7 +116,7 @@ init_config( void )
    */
   if(( my.username && strlen(my.username) > 0 ) &&
     (  my.password && strlen(my.password) > 0 )){
-    add_authorization( WWW, my.username, my.password, "all" ); 
+    add_authorization(WWW, my.username, my.password, "all"); 
   }
   if(my.proxy.hostname && strlen(my.proxy.hostname) > 0){
     my.proxy.required = TRUE;
@@ -167,29 +167,29 @@ show_config( int EXIT )
   printf( "www auth:                       " ); display_authorization( WWW ); 
   printf( "\n" );
 
-  if( EXIT ) exit( 0 );
+  if( EXIT ) exit(0);
   else return 0;
 }
 
 static char
-*get_line( FILE *fp )
+*get_line(FILE *fp)
 {
   char *ptr = NULL;
   char *newline;
   char tmp[256];
 
-  memset( tmp, 0, sizeof( tmp )); 
-  do{
-    if(( fgets( tmp, sizeof( tmp ), fp )) == NULL ) return( NULL );
+  memset( tmp, 0, sizeof(tmp)); 
+  do {
+    if((fgets(tmp, sizeof(tmp), fp)) == NULL) return(NULL);
     if( ptr == NULL ) 
       ptr = xstrdup( tmp );
     else{
       /* no check for NULL needed here, since that is joe_fatal for
 	 xrealloc already */
-      ptr = (char*)xrealloc( ptr, strlen(ptr) + strlen(tmp) + 1 );
+      ptr = (char*)xrealloc(ptr, strlen(ptr) + strlen(tmp) + 1);
       strcat( ptr, tmp );
     }
-    newline = strchr( ptr, '\n' );
+    newline = strchr(ptr, '\n');
   } while( newline == NULL );
   *newline = '\0';
  
@@ -197,16 +197,16 @@ static char
 } 
 
 static char
-*chomp_line( FILE *fp, char **mystr, int *line_num )
+*chomp_line(FILE *fp, char **mystr, int *line_num)
 {
   char *ptr;
-  while( TRUE ){
-    if(( *mystr = get_line( fp )) == NULL) return( NULL );
+  while(TRUE){
+    if((*mystr = get_line( fp )) == NULL) return NULL;
     (*line_num)++;
-    ptr = chomp( *mystr );
+    ptr = chomp(*mystr);
     /* exclude comments */
-    if( *ptr != '#' && *ptr != '\0' ){
-      return( ptr );
+    if(*ptr != '#' && *ptr != '\0'){
+      return(ptr);
     } else {
       xfree(ptr);
     }
@@ -214,7 +214,7 @@ static char
 } 
 
 int
-load_conf( char *filename )
+load_conf(char *filename)
 {
   FILE *fp;
   HASH H;
@@ -224,11 +224,11 @@ load_conf( char *filename )
   char *option;
   char *value;
  
-  if (( fp = fopen(filename, "r")) == NULL ) {
+  if ((fp = fopen(filename, "r")) == NULL) {
     return -1;
   } 
 
-  H = new_hash( 16 );
+  H = new_hash(16);
 
   while((line = chomp_line(fp, &line, &line_num)) != NULL){
     tmp    = line;
@@ -335,6 +335,12 @@ load_conf( char *filename )
       else
         my.bench = FALSE;
     }
+    else if(strmatch(option, "cache")){
+      if(!strncasecmp(value, "true", 4)) 
+        my.cache = TRUE;
+      else
+        my.cache = FALSE;
+    }
     else if(strmatch( option, "debug")){
       if(!strncasecmp( value, "true", 4))
         my.debug = TRUE;
@@ -346,7 +352,7 @@ load_conf( char *filename )
       strncpy(my.file, value, sizeof(my.file));
     }
     else if(strmatch(option, "url")){
-      my.url = (char*)strdup(value); 
+      my.url = stralloc(value);
     }
     else if(strmatch(option, "user-agent")){
       strncpy(my.uagent, value, sizeof(my.uagent));
@@ -358,7 +364,7 @@ load_conf( char *filename )
       if(strmatch(option, "login-url")){  
         /* login URL */
         my.login = TRUE;
-        my.loginurl = value;
+        my.loginurl = stralloc(value);
       } else {
         /* user login info */
         char *usr, *pwd, *rlm;
@@ -369,7 +375,7 @@ load_conf( char *filename )
         while( *value && *value != ':' && *value != '\0' )
         value++;
         *value++=0; rlm = value;
-        add_authorization( WWW, usr, pwd, rlm );
+        add_authorization(WWW, usr, pwd, rlm);
       }
     }
     else if(strmatch(option, "attempts")){
@@ -380,10 +386,10 @@ load_conf( char *filename )
       }
     }
     else if(strmatch(option, "username")){
-      my.username = trim(value);
+      my.username = stralloc(trim(value));
     }
     else if(strmatch(option, "password")){
-      my.password = trim(value);
+      my.password = stralloc(trim(value));
     }
     else if(strmatch(option, "connection")){
       if(!strncasecmp(value, "keep-alive", 10))
