@@ -420,15 +420,20 @@ main(int argc, char *argv[])
   /**
    * loop until my.cusers and create a corresponding thread...
    */  
-  for( x = 0; x < my.cusers && crew_get_shutdown(crew) != TRUE; x++ ){
-    client[x].id    = x; 
-    client[x].bytes = 0;
-    client[x].time  = 0.0;
-    client[x].hits  = 0;
-    client[x].code  = 0;
-    client[x].fail  = 0; 
-    client[x].U     = urls;
-    client[x].rand_r_SEED = pthread_rand_np(&randrseed);
+  for(x = 0; x < my.cusers && crew_get_shutdown(crew) != TRUE; x++){
+    client[x].id              = x; 
+    client[x].bytes           = 0;
+    client[x].time            = 0.0;
+    client[x].hits            = 0;
+    client[x].code            = 0;
+    client[x].ok200           = 0;   
+    client[x].fail            = 0; 
+    client[x].U               = urls;
+    client[x].auth.www        = 0;
+    client[x].auth.proxy      = 0;
+    client[x].auth.type.www   = BASIC;
+    client[x].auth.type.proxy = BASIC;
+    client[x].rand_r_SEED     = pthread_rand_np(&randrseed);
     result = crew_add(crew, (void*)start_routine, &(client[x]));
     if(result == FALSE){ 
       my.verbose = FALSE;
@@ -455,6 +460,7 @@ main(int argc, char *argv[])
     data_increment_bytes(D, client[x].bytes);
     data_increment_total(D, client[x].time);
     data_increment_code (D, client[x].code);
+    data_increment_ok200(D, client[x].ok200);
     data_increment_fail (D, client[x].fail);
     data_set_highest    (D, client[x].bigtime);
     data_set_lowest     (D, client[x].smalltime);
@@ -510,6 +516,9 @@ main(int argc, char *argv[])
   fprintf(stderr, "Throughput:\t\t%12.2f MB/sec\n",        data_get_throughput(D));
   fprintf(stderr, "Concurrency:\t\t%12.2f\n",              data_get_concurrency(D));
   fprintf(stderr, "Successful transactions:%12u\n",        data_get_code(D)); 
+  if(my.debug){
+    fprintf(stderr, "HTTP OK received:\t%12u\n",             data_get_ok200(D));
+  }
   fprintf(stderr, "Failed transactions:\t%12u\n",          my.failed);
   fprintf(stderr, "Longest transaction:\t%12.2f\n",        data_get_highest(D));
   fprintf(stderr, "Shortest transaction:\t%12.2f\n",       data_get_lowest(D));
