@@ -1,7 +1,7 @@
 /**
  * SIEGE socket library
  *
- * Copyright (C) 2000-2007 by
+ * Copyright (C) 2000-2008 by
  * Jeffrey Fulmer - <jeff@joedog.org>, et al. 
  * This file is distributed as part of Siege 
  *
@@ -132,7 +132,7 @@ new_socket(CONN *C, const char *hostparam, int portparam)
   }
 # endif/*HAVE_GETIPNODEBYNAME*/
 #elif defined(_AIX)
-  aixbuf = (char*)xmalloc( 9000 );
+  aixbuf = (char*)xmalloc(9000);
   rc  = gethostbyname_r(hn, (struct hostent *)aixbuf,
                        (struct hostent_data *)(aixbuf + sizeof(struct hostent)));
   hp = (struct hostent*)aixbuf;
@@ -141,11 +141,11 @@ new_socket(CONN *C, const char *hostparam, int portparam)
   herrno = h_errno;
 #else
   /* simply hoping that gethostbyname is thread-safe */
-  hp = gethostbyname( hn );
+  hp = gethostbyname(hn);
   herrno = h_errno;
 #endif/*OS SPECIFICS*/ 
 
-  if( hp == NULL ){ return -1; } 
+  if(hp == NULL){ return -1; } 
   memset((void*) &cli, 0, sizeof(cli));
   memcpy(&cli.sin_addr, hp->h_addr, hp->h_length);
 #if defined(sun)
@@ -180,6 +180,7 @@ new_socket(CONN *C, const char *hostparam, int portparam)
    * readability/writeability of the socket....
    */ 
   conn = connect(C->sock, (struct sockaddr *)&cli, sizeof(struct sockaddr_in));
+  pthread_testcancel();
   if(conn < 0 && errno != EINPROGRESS){
     switch(errno){
       case EACCES:        {joe_error("socket: %d EACCES",                  pthread_self()); break;}
@@ -257,6 +258,7 @@ __socket_check(CONN *C, SDSET mode)
 
   do {
     res = select(C->sock + 1, rs, ws, NULL, &timeout);
+    pthread_testcancel();
   } while(res < 0 && errno == EINTR);
 
   if(mode==WRITE){
@@ -308,7 +310,7 @@ __socket_block(int sock, BOOLEAN block)
     flags &= ~O_NDELAY;
   } else {
     flags |=  O_NDELAY;
-    #if (defined(hpux) || defined(__hpux) || defined(__osf__))
+    #if (defined(hpux) || defined(__hpux) || defined(__osf__)) || defined(__sun)
     #else
     flags |=  O_NONBLOCK;
     #endif
