@@ -24,6 +24,7 @@
 #include <stdlib.h>
 #include <setup.h>
 #include <load.h>
+#include <date.h>
 #include <joedog/joedog.h>
 #include <joedog/boolean.h>
 
@@ -171,6 +172,63 @@ insert_childid(URL *U, int mypid)
   }
 }
 
+void
+url_set_expires(URL *U, int secs)
+{
+  time_t now;
+ 
+  now  = time(NULL);
+  U->expires = adjust(now, secs);  
+  U->cached  = TRUE;
+
+  return;
+}
+
+void
+url_set_last_modified(URL *U, char *date)
+{
+  U->modified = strtotime(date);
+  return; 
+}
+
+void 
+url_set_etag(URL *U, char *etag)
+{
+  size_t len;
+  if(empty(etag)) return;
+
+  len = strlen(etag)+1;
+  U->etag = xmalloc(len);
+  memset(U->etag, 0, sizeof U->etag);
+  strncpy(U->etag, etag, len);
+  return;
+}
+
+char *
+url_get_if_modified_since(URL *U)
+{
+  if(U->cached == FALSE){
+    return NULL; 
+  }
+
+  return timetostr(&U->modified);
+}
+
+char *
+url_get_etag(URL *U)
+{
+  char   *tag;
+  size_t len;
+
+  if(empty(U->etag)) return NULL; 
+
+  len = strlen(U->etag) + 18;
+  tag = xmalloc(len);
+  memset(tag, 0, sizeof tag);
+
+  snprintf(tag, len, "If-None-Match: %s\015\012", U->etag);
+  return tag;
+}
 
 char *
 url_encode(char *str)
@@ -182,27 +240,26 @@ url_encode(char *str)
   static char char2hex[16] = "0123456789ABCDEF";
 
   bk = ch  = str;
-  do{
-    if( strchr( unsafe, *ch ))
+  do {
+    if(strchr(unsafe, *ch))
       size += 2;
     ch++; size ++;
-  } while( *ch );
+  } while(*ch);
 
-  buf = (char*)malloc( size +1 );
+  buf = (char*)malloc(size +1);
   p   = buf;
   ch  = bk;
   do{
-    if( strchr( unsafe, *ch )){
+    if(strchr(unsafe, *ch)){
       const char c = *ch;
       *p++ = '%';
       *p++ = char2hex[(c >> 4) & 0xf];
       *p++ = char2hex[c & 0xf];
-    }
-    else{
+    } else {
       *p++ = *ch;
     }
     ch ++;
-  } while( *ch );
+  } while(*ch);
 
   *p = '\0';
   return(buf);
@@ -246,7 +303,7 @@ build_from_template(URL *U, int rand)
 void
 process_post_data(URL *U, char *datap)
 {
-  for( ; isspace((unsigned int)*datap); datap++ ){
+  for(; isspace((unsigned int)*datap); datap++){
     /* Advance past white space */
   }
   if(*datap == '<'){
@@ -272,8 +329,12 @@ build_url(char *url, int defaultport, int id)
 
   U = xcalloc(sizeof(URL), 1);
   U->urlid = id;
-
+  U->expires  = 0;
+  U->modified = 0;
+  U->cached   = FALSE;
+  
   post_cmd = strstr(url, " POST"); 
+
   if( post_cmd != NULL ){
     /* How do we deal with handling the multi-headed url_t arrays */
     U->calltype = URL_POST;
@@ -366,6 +427,7 @@ build_url(char *url, int defaultport, int id)
     (U->protocol==HTTP)?"http://":"https://", U->hostname, U->port, U->pathname
   );
 
+
   xfree(url); 
   xfree(tmp);
   return(U);
