@@ -61,6 +61,10 @@ typedef struct
   char      *posttemp;
   char      *conttype;
   char      url[MAX_URL];
+  time_t    expires;
+  time_t    modified;
+  BOOLEAN   cached;
+  char      *etag;
 } URL;
 
 int      protocol_length(char *url); 
@@ -68,6 +72,11 @@ BOOLEAN  is_supported(char* url);
 int      get_default_port(PROTOCOL p);
 PROTOCOL get_protocol(const char *url);
 void     insert_childid(URL *U, int mypid);
+void     url_set_last_modified(URL *U, char *date);
+void     url_set_etag(URL *U, char *etag);
+void     url_set_expires(URL *U, int secs);
+char     *url_get_if_modified_since(URL *U);
+char     *url_get_etag(URL *U);
 URL      *build_url(char *url, int defaultport, int id);
 URL      *add_redirect(char *url, int port, int id);
 URL      *add_url(char *url, int id);
